@@ -51,8 +51,6 @@ class DipoleError(Exception):
 class NegativeError(Exception):
     pass
 
-__version__ = 1.1.0
-
 # Some default starting points on the sky to consider
 QSO_RA = "22h20m06.757" # RA
 QSO_DEC = "-28d03m23.34" # DEC
@@ -181,9 +179,6 @@ def dipole_monopole(right_ascension=QSO_RA, \
     
     """
     pos1 = angles.AngularPosition(alpha=right_ascension, delta=declination)
-    if verbose == True:
-        print "Sky position: ", pos1
-        print "Dipole position: ", 
     return wrap_dipole_monopole(amplitude, \
                                 wrap_sep(wrap_radian_RA(dipole_ra), \
                                          wrap_radian_DEC(dipole_dec), \
